@@ -327,7 +327,7 @@ def ssh_add_key(env, key):
                     stderr=PIPE, env=env)
     (_, error) = process.communicate(input=str.encode(key))
     if process.returncode and error:
-        logging.error('failed to add ssh key: %s', error)
+        logging.error('failed to add ssh key: %s', error.decode('utf-8'))
 
 
 def ssh_cleanup_agent():
@@ -357,7 +357,7 @@ def ssh_setup_agent(envkeys=None):
     envkeys = envkeys or ['SSH_PRIVATE_KEY', 'SSH_PRIVATE_KEY_FILE']
     (_, output) = run_cmd(['ssh-agent', '-s'], env=env,
                           cwd=ctx.kas_work_dir)
-    for line in output:
+    for line in output.split('\n'):
         matches = re.search(r"(\S+)\=(\S+)\;", line)
         if matches:
             env[matches.group(1)] = matches.group(2)
@@ -368,13 +368,13 @@ def ssh_setup_agent(envkeys=None):
             key_path = os.environ.get(envkey)
             if key_path:
                 found = True
-                logging.info("adding SSH key")
+                logging.info(f"adding SSH key from file '{key_path}'")
                 ssh_add_key_file(env, key_path)
         else:
             key = os.environ.get(envkey)
             if key:
                 found = True
-                logging.info("adding SSH key")
+                logging.info("adding SSH key from env-var 'SSH_PRIVATE_KEY'")
                 ssh_add_key(env, key)
 
     if found is not True:
