@@ -84,9 +84,9 @@ from kas.kasusererror import KasUserError
 try:
     from snack import SnackScreen, EntryWindow, ButtonChoiceWindow, \
         ButtonBar, Listbox, GridFormHelp
-    newt_available = True
+    HAVE_NEWT = True
 except ImportError:
-    newt_available = False  # will be reported in run()
+    HAVE_NEWT = False  # will be reported in run()
 
 __license__ = 'MIT'
 __copyright__ = \
@@ -113,8 +113,7 @@ class KConfigLoadError(KasUserError):
 
 def check_sym_is_string(sym):
     if sym.type != STRING:
-        raise VariableTypeError('Variable {} must be of string type'
-                                .format(sym.name))
+        raise VariableTypeError(f'Variable {sym.name} must be of string type')
 
 
 def str_representer(dumper, data):
@@ -195,8 +194,8 @@ class Menu:
                     menu_configuration[symname] = int(symvalue, 16)
                 else:
                     raise VariableTypeError(
-                        'Configuration variable {} uses unsupported type'
-                        .format(symname))
+                        'Configuration variable {symname} uses unsupported '
+                        'type')
 
             if symname.startswith('KAS_INCLUDE_'):
                 check_sym_is_string(sym)
@@ -232,7 +231,7 @@ class Menu:
         if len(kas_vars) > 0:
             config['local_conf_header'] = {
                 '__menu_config_vars': '\n'.join([
-                    '{} = "{}"'.format(key, value)
+                    f'{key} = "{value}"'
                     for key, value in kas_vars.items()
                 ])
             }
@@ -253,8 +252,8 @@ class Menu:
             with open(filename, 'w') as config_file:
                 config_file.write(
                     '#\n'
-                    '# Automatically generated by kas {}\n'
-                    '#\n'.format(__version__))
+                    f'# Automatically generated by kas {__version__}\n'
+                    '#\n')
                 yaml.dump(config, config_file)
 
     def dump_kconf_warnings(self):
@@ -263,7 +262,7 @@ class Menu:
             self.kconf.warnings = []
 
     def run(self, args):
-        if not newt_available:
+        if not HAVE_NEWT:
             raise MissingModuleError(
                 'Menu plugin requires \'python3-newt\' distribution package.')
 
@@ -314,7 +313,7 @@ class Menuconfig():
         Returns the value part ("[*]", "(foo)" etc.) of a menu entry.
         """
         if sym.type in (STRING, INT, HEX):
-            return "({})".format(sym.str_value)
+            return f"({sym.str_value})"
 
         # BOOL (TRISTATE not supported)
 
@@ -328,10 +327,10 @@ class Menuconfig():
 
         if len(sym.assignable) == 1:
             # Pinned to a single value
-            return "-{}-".format(tri_val_str)
+            return f"-{tri_val_str}-"
 
         if sym.type == BOOL:
-            return "[{}]".format(tri_val_str)
+            return f"[{tri_val_str}]"
 
         raise RuntimeError()
 
@@ -363,13 +362,13 @@ class Menuconfig():
             return ""
 
         if node.item == MENU:
-            return "    " + indent * " " + prompt + "  --->"
+            return f"    {indent * ' '}{prompt}  --->"
 
-        if type(node.item) == Choice:
-            return "    " + indent * " " + prompt
+        if type(node.item) is Choice:
+            return f"    {indent * ' '}{prompt}"
 
         if node.item == COMMENT:
-            return "    " + indent * " " + "*** {} ***".format(prompt)
+            return f"    {indent * ' '}*** {prompt} ***"
 
         # Symbol
         sym = node.item
@@ -379,12 +378,11 @@ class Menuconfig():
 
         # {:3} sets the field width to three. Gives nice alignment for empty
         # string values.
-        res = "{:3} {}{}".format(Menuconfig.value_str(sym), indent * " ",
-                                 prompt)
+        res = f"{Menuconfig.value_str(sym):3} {indent * ' '}{prompt}"
 
         # Append a sub-menu arrow if menuconfig and enabled
         if node.is_menuconfig:
-            res += "  ---" + (">" if sym.tri_value > 0 else "-")
+            res += f"  ---{'>' if sym.tri_value > 0 else '-'}"
 
         return res
 
@@ -398,7 +396,7 @@ class Menuconfig():
                 items.append((string, node))
 
             if (node.list and node.item != MENU
-                    and (type(node.item) == Choice or not node.is_menuconfig)):
+                    and (type(node.item) is Choice or not node.is_menuconfig)):
                 items.extend(Menuconfig.menu_node_strings(node.list,
                                                           indent + 2))
 
@@ -406,7 +404,7 @@ class Menuconfig():
 
         return items
 
-    def show_menu(self, title, top_node):
+    def show_menu(self, title, top_node, is_submenu=False):
         selection = 0
 
         while True:
@@ -419,12 +417,16 @@ class Menuconfig():
                 scroll = 1
 
             buttons = [
-                ('Save & Build', 'build', 'B'),
+                ('Build', 'build', 'B'),
                 ('Save & Exit', 'save', 'S'),
-                (' Help ', 'help', 'h'),
-                (' Exit ', 'exit', 'ESC')
+                (' Exit ', 'exit', 'E'),
+                (' Help ', 'help', 'h')
             ]
+            if is_submenu:
+                buttons.insert(0, (' Return ', 'return', 'ESC'))
             buttonbar = ButtonBar(self.screen, buttons)
+            if not is_submenu:
+                buttonbar.hotkeys['ESC'] = 'exit'
             listbox = Listbox(height, scroll=scroll, returnExit=1)
             count = 0
             for string, _ in items:
@@ -459,7 +461,7 @@ class Menuconfig():
                     help = 'No help available.'
                 ButtonChoiceWindow(
                     screen=self.screen,
-                    title="Help on '{}'".format(prompt),
+                    title=f"Help on '{prompt}'",
                     text=help,
                     width=60,
                     buttons=['  Ok  '])
@@ -467,7 +469,7 @@ class Menuconfig():
 
             show_submenu = False
 
-            if type(sym) == Symbol:
+            if type(sym) is Symbol:
                 if rc == ' ':
                     if sym.type == BOOL:
                         sym.set_value('n' if sym.tri_value > 0 else 'y')
@@ -478,7 +480,7 @@ class Menuconfig():
                         action, values = EntryWindow(
                             screen=self.screen,
                             title=sym.name,
-                            text='Enter a %s value:' % TYPE_TO_STR[sym.type],
+                            text=f'Enter a {TYPE_TO_STR[sym.type]} value:',
                             prompts=[('', sym.str_value)],
                             buttons=[('  Ok  ', 'Ok'), ('Cancel', '', 'ESC')])
                         if action == 'Ok':
@@ -497,14 +499,15 @@ class Menuconfig():
                                     width=60,
                                     buttons=['  Ok  '])
                                 self.kconf.warnings = []
-            elif selected_node.is_menuconfig and type(sym) != Choice:
+            elif selected_node.is_menuconfig and type(sym) is not Choice:
                 show_submenu = True
 
             if show_submenu:
                 submenu_title, _ = selected_node.prompt
                 action = self.show_menu(submenu_title,
-                                        selected_node.list)
-                if action != 'exit':
+                                        selected_node.list,
+                                        is_submenu=True)
+                if action != 'return':
                     return action
 
     def show(self):
